<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/partner_settings.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class AdminSettings extends TeamServer {
    private static $instance = NULL;

    public function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startSettings() {
        if ( check_post( 'savesettings' ) ) {
			$inputArray = [
				'team_submit'        => post( 'team_submit' ) ? 1 : 0,
				'team_submit_access' => sanitizer( ['team_submit_access'], 0, 'team_submit_access' ),
				'team_photo_w'       => sanitizer( 'team_photo_w', '1024', 'team_photo_w' ),
				'team_photo_h'       => sanitizer( 'team_photo_h', '768', 'team_photo_h' ),
				'team_photo_b'       => sanitizer( 'calc_b', '15', 'calc_b' ) * sanitizer( 'calc_c', '100000', 'calc_c' ),
				'team_pagination'    => sanitizer( 'team_pagination', 0, 'team_pagination' ),
				'team_file_types'    => sanitizer( ['team_file_types'], '.gif,.jpg,.png,.svg,.webp', 'team_file_types' )
			];

            if ( fusion_safe() ) {
                foreach ( $inputArray as $settings_name => $settings_value ) {
                    $inputSettings = [
                        'settings_name'  => $settings_name,
                        'settings_value' => $settings_value,
                        'settings_inf'   => TEAM_FOLDER
                    ];
                    dbquery_insert( DB_SETTINGS_INF, $inputSettings, 'update', ['primary_key' => 'settings_name'] );
                }
                addnotice( 'success', self::$locale['TEAM_015'] );
                redirect( clean_request( '', ['section', 'aid'], TRUE ) );
            }
        }

        opentable( self::$locale['TEAM_011'] );
        openside( ' ' );
        echo openform( 'settingsform', 'POST' );
        echo self::settingsForm();
        closeside();
        echo form_button('savesettings', self::$locale['save'], self::$locale['save'], ['class' => 'btn-success', 'icon' => 'fa fa-hdd-o']);
        closeform();
        closetable();
    }

    private function settingsForm() {
        $mime = mimetypes();
        $mime_opts = [];
        foreach ( $mime as $m => $Mime ) {
            $ext = ".$m";
            $mime_opts[$ext] = $ext;
        }
        $html = form_text( 'team_photo_w', self::$locale['TEAM_016'], $this->teamSettings['team_photo_w'], [
            'required'       => TRUE,
            'inline'         => TRUE,
            'max_length'     => 4,
            'type'           => 'number',
            'prepend'        => TRUE,
            'floating_label' => TRUE
        ] );
        $html .= form_text( 'team_photo_h', self::$locale['TEAM_017'], $this->teamSettings['team_photo_h'], [
            'required'       => TRUE,
            'inline'         => TRUE,
            'max_length'     => 4,
            'type'           => 'number',
            'prepend'        => TRUE,
            'floating_label' => TRUE
        ] );
        $calc_c = calculate_byte( $this->teamSettings['team_photo_b'] );
        $calc_b = $this->teamSettings['team_photo_b'] / $calc_c;
        $html .= form_text( 'calc_b', self::$locale['TEAM_018'], $calc_b, [
            'required'    => TRUE,
            'inline'      => TRUE,
            'type'        => 'number',
            'error_text'  => self::$locale['error_rate'],
            'width'       => '100%',
            'max_length'  => 4,
            'append'      => TRUE,
            'append_html' => form_select( 'calc_c', '', $calc_c, [
                'options'     => [
                    1       => self::$locale['global_461'],
                    1024    => 'Kb',
                    1048576 => 'Mb'
                ], // $locale['admins_1020'],
                'placeholder' => self::$locale['choose'],
                'class'       => 'm-0',
                'width'       => '100',
                'inner_width' => '100px'
            ] )
        ] );
        $html .= form_select( 'team_file_types[]', self::$locale['TEAM_019'], $this->teamSettings['team_file_types'], [
            'required' => TRUE,
            'options'  => $mime_opts,
            'inline'   => TRUE,
            'multiple' => TRUE
        ] );
        $html .= form_text( 'team_pagination', self::$locale['TEAM_020'], $this->teamSettings['team_pagination'], [
            'required'    => TRUE,
            'inline'      => TRUE,
            'number'      => TRUE,
            'max_length'  => 4,
            'type'        => 'number',
            'inner_width' => '150px'
        ] );
        $html .= form_select( 'team_submit_access[]', self::$locale['submit_access'], $this->teamSettings['team_submit_access'], [
            'inline'   => TRUE,
            'options'  => fusion_get_groups( [USER_LEVEL_PUBLIC] ),
            'multiple' => TRUE
        ] );
        $html .= form_checkbox( 'team_submit', self::$locale['TEAM_021'], $this->teamSettings['team_submit'], [
            'inline' => TRUE,
            'toggle' => TRUE
        ] );
        return $html;
    }
}
