<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/cat_admin.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class AdminUser extends TeamServer {
    private static $instance = NULL;

    public function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startUserAdmin() {
        switch ( $this->action ) {
            case "newuser":
                self::teamUserForm();
                break;
            case "edituser":
                self::teamUserForm( get( 'team_id', FILTER_VALIDATE_INT ) );
                break;
            case "deleteuser":
                if ( iADMIN && get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::delTeamUser( get( 'team_id', FILTER_VALIDATE_INT ) );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "publishuser":
                if ( get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 1, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_031'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "unpublishuser":
                if ( get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 0, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_032'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            default:
                self::userList();
                break;
        }
    }

    private function editTeamUser( $teamuser = NULL ) {
        if ( !empty( $teamuser ) && isnum( $teamuser ) ) {
            $result = dbquery( $this->sqlTeam->getTeamUserQuery( ['condition' =>"team_id = :tgid"] ), [':tgid' => $teamuser] );
            if ( dbrows( $result ) ) {
                $this->def_teamuser = dbarray( $result );
            } else {
                redirect( clean_request( '', ['action'], FALSE ) );
            }
        }
    }

    private function teamUserForm( $teamuser = NULL) {
        if ( !empty( $teamuser ) ) {
            self::editTeamUser( $teamuser );
        }
        if ( check_post( 'save_group' ) ) {

            $inputData = [
                'team_id'          => sanitizer( 'team_id', '', 'team_id' ),
                'team_user_id'     => sanitizer( 'team_user_id', 0, 'team_user_id' ),
                'team_pic'         => sanitizer( 'team_pic', '', 'team_pic' ),
                'team_real_name'   => sanitizer( 'team_real_name', '', 'team_real_name' ),
                'team_position'    => sanitizer( 'team_position', '', 'team_position' ),
                'team_description' => sanitizer( 'team_description', '', 'team_description' ),
                'team_status'      => sanitizer( 'team_status', 0, 'team_status' ),
                'team_active'      => sanitizer( 'team_active', 0, 'team_active' ),
                'team_email'       => sanitizer( 'team_email', '', 'team_email' ),
                'team_datestamp'   => post( 'team_datestamp' ) ? sanitizer( 'team_datestamp', 0, 'team_datestamp' ) : time(),
                'team_language'    => sanitizer( 'team_language', LANGUAGE, 'team_language' )
            ];

            if ( fusion_safe() && !empty( $_FILES['team_pic'] ) && is_uploaded_file( $_FILES['team_pic']['tmp_name'] ) ) {
                $upload = form_sanitizer( $_FILES['team_pic'], '', 'team_pic' );
                if ( empty( $upload['error'] ) ) {
                    $inputData['team_pic'] = $upload['image_name'];
                }
            } else if ( check_post( 'del_image' ) && check_post( 'team_id' ) && post( 'team_id', FILTER_VALIDATE_INT ) ) {
                $result = dbquery("SELECT team_pic FROM ".DB_TEAM." WHERE team_id = :teamid", [':teamid' => post( 'team_id' )] );
                if ( dbrows( $result ) ) {
                    $data = dbarray( $result );
                    if ( !empty( $data['team_pic'] ) && file_exists( TEAM_IMG . 'team/' . $data['team_pic'] ) ) {
                        @unlink( TEAM_IMG . 'team/' . $data['team_pic'] );
                    }
                }
                $inputData['team_pic'] = '';
            }
            if ( fusion_safe() ) {
                dbquery_insert( DB_TEAM, $inputData, empty( $inputData['team_id'] ) ? 'save' : 'update' );
                addnotice( 'success', empty( $inputData['team_id'] ) ? self::$locale['TEAM_033'] : self::$locale['TEAM_034'] );
                redirect( clean_request( '', ['action'], FALSE ) );
            }
        }

        $image_team = makefilelist( TEAM_IMG . 'team/', ".|..|index.php", TRUE );
        $result = dbquery( $this->sqlTeam->getUsersQuery( ['order' => "user_level DESC, user_name"] ) );
        $teamuser = [0 => self::$locale['TEAM_035']];
        while ( $member_list = dbarray( $result ) ) {
            $teamuser[$member_list['user_id']] = $member_list['user_name'];
        }

        $info = [
            'openform'         => openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20']  ),
            'team_id'          => form_hidden( 'team_id', '', $this->def_teamuser['team_id'] ),
            'team_user_id'     => form_select( 'team_user_id', self::$locale['TEAM_036'], $this->def_teamuser['team_user_id'], [
                'inline'      => TRUE,
                'options'     => $teamuser,
                'placeholder' => self::$locale['choose'],
            ] ),
            'team_pic'         => !empty( $this->def_teamuser['team_pic'] ) ?
                "<div id='team_user_id-field' class='form-group row'>
                    <label class='control-label col-xs-12 col-sm-12 col-md-3 col-lg-3'>" . self::$locale['TEAM_037'] . "</label>
                    <div class='col-xs-12 col-sm-12 col-md-9 col-lg-9'>
                        <div class='text-left m-r-10'>
                            " . thumbnail( TEAM_IMG . 'team/' . $this->def_teamuser['team_pic'], '80px' ) . "
                        </div>
                        <div class='overflow-hide'>
                            " . form_checkbox( 'del_image', self::$locale['delete'], '' ) .
                            form_hidden( 'team_pic', '', $this->def_teamuser['team_pic'] ) . "
                        </div>
                    </div>
                </div>" : form_fileinput( 'team_pic', self::$locale['TEAM_037'], '', [
                    'upload_path'     => TEAM_IMG . 'team/',
                    'inline'          => TRUE,
                    'multiple'        => FALSE,
                    'delete_original' => FALSE,
                    'template'        => 'modern',
                    'class'           => 'm-b-0',
                    'max_width'       => $this->teamSettings['team_photo_w'],
                    'max_height'      => $this->teamSettings['team_photo_h'],
                    'max_byte'        => $this->teamSettings['team_photo_b'],
                    'ext_tip'         => sprintf( self::$locale['TEAM_038'], parsebytesize( $this->teamSettings['team_photo_b'] ), str_replace( ',', ' ', ".jpg,.gif,.png" ), $this->teamSettings['team_photo_w'], $this->teamSettings['team_photo_h'] )
            ] ),
            'team_real_name'   => form_text( 'team_real_name', self::$locale['TEAM_039'], $this->def_teamuser['team_real_name'], [
                'inline'     => TRUE,
                'required'   => TRUE,
                'error_text' => '' //self::$locale['ERROR_04']
            ] ),
            'team_position'    => form_text( 'team_position', self::$locale['TEAM_040'], $this->def_teamuser['team_position'], [
                'inline'     => TRUE,
                'required'   => TRUE,
            ] ),
            'team_description' => form_textarea( 'team_description', self::$locale['TEAM_041'], $this->def_teamuser['team_description'], [
                'inline'    => TRUE,
                'html'      => TRUE,
                'form_name' => 'groupFrm'
            ] ),
            'team_email'       => form_text( 'team_email', self::$locale['TEAM_042'], $this->def_teamuser['team_email'], [
                'type'       => 'email',
                'required'   => TRUE,
                'inline'     => TRUE,
                'max_length' => '100',
                'error_text' => self::$locale['TEAM_058'],
                //'ext_tip'    => $ext_tip
            ]),
            'team_phone'       => form_text( 'team_phone', self::$locale['TEAM_044'], $this->def_teamuser['team_phone'], [
                'inline'      => TRUE,
                'number'      => TRUE,
                'max_length'  => 20,
                'placeholder' => '+36301234567'
            ] ),
            'team_web'         => form_text( 'team_web', self::$locale['TEAM_045'], $this->def_teamuser['team_web'], [
                'inline'      => TRUE,
                'type'        => 'url',
                'regex'       => 'http(s)?\:\/\/(.*?)',
                'placeholder' => 'https://fusionhu.com'
            ] ),
            'team_status'      => form_select( 'team_status', self::$locale['TEAM_043'], $this->def_teamuser['team_status'], [
                'inline'      => TRUE,
                'options'     => [1 => self::$locale['TEAM_048'], 0 => self::$locale['TEAM_049']],
                'placeholder' => self::$locale['choose'],
            ] ),
            'team_active'      => form_select( 'team_active', self::$locale['TEAM_059'], $this->def_teamuser['team_active'], [
                'inline'      => TRUE,
                'options'     => [1 => self::$locale['yes'], 0 => self::$locale['no']],
                'placeholder' => self::$locale['choose'],
            ] ),
            'team_language'    => multilang_table( "TEAM" ) ? form_select( 'team_language[]', self::$locale['language'], $this->def_teamuser['team_language'], [
                'inline'      => TRUE,
                'options'     => fusion_get_enabled_languages(),
                'placeholder' => self::$locale['choose'],
                'inner_width' => '100%',
                'multiple'    => TRUE
            ] ) : form_hidden( 'team_language', '', $this->def_teamuser['team_language'] ),
            'butonsave'        => form_button( 'save_group', self::$locale['save'], self::$locale['save'], ['class' => 'btn-sm btn-primary', 'icon' => 'fa fa-floppy-o'] ),
            'closeform'        => closeform()
        ];
        groupForm( $info );
    }

    private function userList() {
        $inf['tablename'] = self::$locale['TEAM_010'];
        $inf['newlink'] = clean_request( "action=newuser", ["action"], FALSE );

        $rows = dbcount( "(team_id)", DB_TEAM, ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ) : '' ) );
        $rowstart = get_rowstart( "rowstart", $rows );

        $result = dbquery( $this->sqlTeam->getTeamQuery( ['condition' => ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ) : '' ), 'order' => "team_real_name ASC" , 'limit' => $rowstart . "," . $this->teamSettings['team_pagination']] ) );
        if ( dbrows( $result ) ) {
            while ( $tl_users = dbarray( $result ) ) {
                $alink = empty( $tl_users['team_status'] ) ? 'publishuser' : 'unpublishuser';
                $activetitle = empty( $tl_users['team_status'] ) ? self::$locale['TEAM_046'] : self::$locale['TEAM_047'];
                $useredit = clean_request( "section=users&action=edituser&team_id=" . $tl_users['team_id'], ['section', 'action', 'team_id', 'rowstart'], FALSE );
                $userdelete = clean_request( "section=users&action=deleteuser&team_id=" . $tl_users['team_id'], ['section', 'action', 'team_id', 'rowstart'], FALSE );
                $useractive = clean_request( "section=users&action=" . $alink . "&team_id=" . $tl_users['team_id'], ['section', 'action', 'team_id', 'rowstart'], FALSE);
                $status = self::getTeamIcons( 'circle', 'm-l-10', ( !empty( $tl_users['team_status'] ) ? self::$locale['TEAM_048'] : self::$locale['TEAM_049'] ), "color:#" . ( !empty( $tl_users['team_status'] ) ? "5CB85C" : "FF4040" ) . ";" );

                $tl_users['useredit'] = "<a href='" . $useredit . "'>" . self::getTeamIcons( 'pencil', 'm-l-10', self::$locale['edit'] ) . "</a>";
                $tl_users['userdelete'] = "<a href='" . $userdelete . "'>" . self::getTeamIcons( 'trash', 'm-l-10', self::$locale['delete'] ) . "</a>";
                $tl_users['useractive'] = "<a href='" . $useractive . "'>" . self::getTeamIcons( ( empty( $tl_users['team_status'] ) ? 'usercheck' : 'userslash' ), 'm-l-10', $activetitle );
                $tl_users['status'] = $status;
                $tl_users['name'] = !empty( $tl_users['team_user_id'] ) ? profile_link( $tl_users['user_id'], $tl_users['user_name'], $tl_users['user_status'] ) : self::$locale['TEAM_050'];
                $tl_users['avatar'] = "<img src='" . TEAM_IMG . 'team/' . $tl_users['team_pic']."' height='50' />";
                $inf['team'][] = $tl_users;
            }
            $inf['page_nav'] = makepagenav( $rowstart, $this->teamSettings['team_pagination'], $rows, 3, FUSION_SELF.fusion_get_aidlink() . '&section=users&' );
        } else {
            $inf['nouser'] = self::$locale['TEAM_053'];
        }
        adminUserInfo( $inf );
    }

    private function delTeamUser( $teamid ) {
        dbquery( "DELETE FROM " . DB_TEAM . " WHERE team_id = :teamid", [':teamid' => (int)$teamid] );
        $result = dbquery( $this->sqlTeam->getTeamUserQuery( ['condition' =>"team_id = :teamid"] ), [':teamid' => $teamid] );
        if ( dbrows( $result ) ) {
            $data = dbarray( $result );
            if ( !empty( $data['team_pic'] ) && file_exists( TEAM_IMG . 'team/' . $data['team_pic'] ) ) {
                @unlink( TEAM_IMG . 'team/' . $data['team_pic'] );
            }
        }
        addnotice( 'success', self::$locale['TEAM_051'] );
    }
}
