<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/team.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class Teams extends TeamServer {
    private static $instance = NULL;
    private $teamdata;

    public function __construct() {
        parent::__construct();
        add_to_title( self::$locale['TEAM_003'] );
    }

    public static function getInstance() {
        if (self::$instance === NULL) {
            self::$instance = new static();
        }
       return self::$instance;
    }

    public function startTeam() {
        switch ( $this->action ) {
            case "viewuser":
                self::teamCount( get( 'team_id' ) );
                self::teamUserView( get( 'team_id' ) );
                break;
            case "edituser":
                self::teamUserEdit( get( 'team_id' ) );
                break;
            case "deleteuser":
                if ( get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamUserDel( get( 'team_id', FILTER_VALIDATE_INT ) );
                    addnotice( 'success', self::$locale['TEAM_051'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "publishuser":
                if ( get( 'team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 1, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_031'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "unpublishuser":
                if ( get( 'team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 0, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_032'] );
                }
                redirect( clean_request( '', ['action', 'team_id'], FALSE ) );
                break;
            default:
                self::dataPartner();
                break;
        }
    }

    private function teamQueryUser( $teamid = NULL ) {
        $result = dbquery( $this->sqlTeam->getTeamQuery( ['condition' =>( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ). 'AND ' : '' ). "team_active = :active AND team_id = :teamid"] ), [':active' => '0', ':teamid' => $teamid] );
        if ( dbrows( $result ) ) {
            $this->teamdata = dbarray( $result );
        } else {
            redirect( FUSION_SELF );
        }
    }

    private function teamUserView( $teamid = NULL ) {
        self::teamQueryUser( $teamid );
        $status = self::getTeamIcons( 'circle', 'm-l-10', ( !empty( $this->teamdata['team_status'] ) ? self::$locale['TEAM_048'] : self::$locale['TEAM_049'] ), "color:#" . ( !empty( $this->teamdata['team_status'] ) ? "5CB85C" : "FF4040" ) . ";" );
        $userdat = $this->teamdata['team_user_id'] == fusion_get_userdata( 'user_id') ? TRUE : FALSE;
        $edit = ( iADMIN && checkrights( 'TEAM' ) || !empty( $userdat ) ? TRUE : FALSE );
        $alink = empty( $this->teamdata['team_status'] ) ? 'publishuser' : 'unpublishuser';
        $activetitle = empty( $this->teamdata['team_status'] ) ? self::$locale['TEAM_046'] : self::$locale['TEAM_047'];

        $info = [
            'avatar'      => "<img src='" . TEAM_IMG . 'team/' . $this->teamdata['team_pic']."' />",
            'real_name'   => $this->teamdata['team_real_name'],
            'status'      => $status,
            'position'    => $this->teamdata['team_position'],
            'name'        => !empty( $this->teamdata['team_user_id'] ) ? profile_link( $this->teamdata['user_id'], $this->teamdata['user_name'], $this->teamdata['user_status'] ) : self::$locale['TEAM_050'],
            'description' => parse_text( $this->teamdata['team_description'], [
                'parse_smileys'        => TRUE,
                'parse_bbcode'         => TRUE,
                'default_image_folder' => NULL,
                'add_line_breaks'      => 'y'
            ] ),
            'profil_link' => [
                'count' => self::getTeamIcons('eye', 'm-r-10') . $this->teamdata['team_count'],
                'email' => ( iADMIN || empty( fusion_get_userdata( 'user_hide_email' ) ) ) ? hide_email( $this->teamdata['team_email'], self::getTeamIcons( 'at', 'm-l-10', self::$locale['UM061a'] ) ) : '',
                'phone' => !empty( $this->teamdata['team_phone'] ) ? self::getTeamIcons( 'phone', 'm-l-10' ) . $this->teamdata['team_phone'] : '',
                'web'   => !empty( $this->teamdata['team_web'] ) ? "<a href='" . $this->teamdata['team_web'] . "' target='_blank'>". self::getTeamIcons( 'globe', 'm-l-10', self::$locale['TEAM_045'] ) . "</a>" : '',
            ],
            'admin_link'  => [
                'useredit'    => !empty( $edit ) ? "<a href='" . TEAM_PATH . "team.php?action=edituser&amp;team_id=" . $this->teamdata['team_id'] . "'>" . self::getTeamIcons( 'pencil', 'm-l-10', self::$locale['edit'] ) . "</a>" : '',
                'userdelete'  => !empty( $edit ) ? "<a href='" . TEAM_PATH . "team.php?action=deleteuser&amp;team_id=" . $this->teamdata['team_id'] . "'>" . self::getTeamIcons( 'trash', 'm-l-10', self::$locale['delete'] ) . "</a>" : '',
                'activelink'  => !empty( $edit ) ? "<a href='" . TEAM_PATH . "team.php?action=" . $alink . "&amp;team_id=" . $this->teamdata['team_id'] . "'>" . self::getTeamIcons( ( empty( $this->teamdata['team_status'] ) ? 'usercheck' : 'userslash' ), 'm-l-10', $activetitle ) . "</a>" : '',
            ],
        ];
        teamWievUser( $info );
    }

    private function dataPartner() {
        $info['tablename'] = self::$locale['TEAM_002'];
        $rows = dbcount( "(team_id)", DB_TEAM, ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ) . ' AND ' : '' ) . "team_active = :active", [':active' => 1] );
        $rowstart = get_rowstart( "rowstart", $rows );

        $result = dbquery( $this->sqlTeam->getTeamQuery( ['condition' =>( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ). 'AND ' : '' ). "team_active = :active", 'order' => "team_status DESC, team_active ASC, team_real_name ASC", 'limit' => $rowstart . "," . $this->teamSettings['team_pagination']] ), [':active' => 0] );
        if ( dbrows( $result ) ) {
            while ( $tl_users = dbarray( $result ) ) {
                $status = self::getTeamIcons( 'circle', 'm-r-10', ( !empty( $tl_users['team_status'] ) ? self::$locale['TEAM_048'] : self::$locale['TEAM_049'] ), "color:#" . ( !empty( $tl_users['team_status'] ) ? "5CB85C" : "FF4040" ) . ";" );
                $infdat['avatar'] = "<a href='" . TEAM_PATH . "team.php?action=viewuser&amp;team_id=" . $tl_users['team_id'] . "'><img src='" . TEAM_IMG . 'team/' . $tl_users['team_pic']."' height='70' /></a>";
                $infdat['real_name'] = $status . $tl_users['team_real_name'];
                $infdat['count'] = self::getTeamIcons('eye', 'm-r-10') . $tl_users['team_count'];
                $infdat['description'] = parse_text( $tl_users['team_description'], [
                    'parse_smileys'        => TRUE,
                    'parse_bbcode'         => FALSE,
                    'default_image_folder' => NULL,
                    'add_line_breaks'      => 'y'
                ] );
                $info['team'][] = $infdat;
            }
        } else {
            $info['nouser'] = self::$locale['TEAM_053'];
        }

        showTeamList( $info );
    }

    private function teamUserEdit( $teamid = NULL ) {
        self::teamQueryUser( $teamid );
        $userdat = $this->teamdata['team_user_id'] == fusion_get_userdata( 'user_id') ? TRUE : FALSE;
        $edit = ( iADMIN && checkrights( 'TEAM' ) || !empty( $userdat ) ? TRUE : FALSE );

        if ( !empty( $edit ) ) {
            if ( check_post( 'save_user' ) ) {
                $inputData = [
                    'team_id'          => sanitizer( 'team_id', '', 'team_id' ),
                    'team_user_id'     => sanitizer( 'team_user_id', 0, 'team_user_id' ),
                    'team_pic'         => sanitizer( 'team_pic', '', 'team_pic' ),
                    'team_real_name'   => sanitizer( 'team_real_name', '', 'team_real_name' ),
                    'team_position'    => sanitizer( 'team_position', '', 'team_position' ),
                    'team_description' => sanitizer( 'team_description', '', 'team_description' ),
                    'team_status'      => sanitizer( 'team_status', 0, 'team_status' ),
                    'team_email'       => sanitizer( 'team_email', '', 'team_email' ),
                    'team_phone'       => sanitizer( 'team_phone', '', 'team_phone' ),
                    'team_web'         => sanitizer( 'team_web', '', 'team_web' ),
                    'team_datestamp'   => post( 'team_datestamp' ) ? sanitizer( 'team_datestamp', 0, 'team_datestamp' ) : time(),
                    'team_language'    => sanitizer( 'team_language', LANGUAGE, 'team_language' )
                ];
                if ( fusion_safe() ) {
                    dbquery_insert( DB_TEAM, $inputData, 'update' );
                    addnotice( 'success', self::$locale['TEAM_034'] );
                    redirect( clean_request( '', ['action', 'team_id'], FALSE ) );
                }
            }
            $image_team = makefilelist( TEAM_IMG . 'team/', ".|..|index.php", TRUE );
            $result = dbquery( $this->sqlTeam->getUsersQuery( ['order' => "user_level DESC, user_name"] ) );
            $teamuser = [0 => self::$locale['TEAM_035']];
            while ( $member_list = dbarray( $result ) ) {
                $teamuser[$member_list['user_id']] = $member_list['user_name'];
            }
            $info = [
                'openform'         => openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] ),
                'team_id'          => form_hidden( 'team_id', '', $this->teamdata['team_id'] ),
                'team_user_id'    => form_select( 'team_user_id', self::$locale['TEAM_036'], $this->teamdata['team_user_id'], [
                    'inline'      => TRUE,
                    'options'     => $teamuser,
                    'placeholder' => self::$locale['choose'],
                ] ),
                'team_pic'         => form_select( 'team_pic', self::$locale['TEAM_037'], $this->teamdata['team_pic'], [
                    'inline'      => TRUE,
                    'keyflip'     => TRUE,
                    'options'     => $image_team,
                    'placeholder' => self::$locale['choose'],
                    'inner_width' => '100%',
                    'max_select'  => TRUE,
                    'multiple'    => TRUE
                ] ),
                'team_real_name'   => form_text( 'team_real_name', self::$locale['TEAM_039'], $this->teamdata['team_real_name'], [
                    'inline'     => TRUE,
                    'required'   => TRUE,
                    'error_text' => '' //self::$locale['ERROR_04']
                ] ),
                'team_position'    => form_text( 'team_position', self::$locale['TEAM_040'], $this->teamdata['team_position'], [
                    'inline'     => TRUE,
                    'required'   => TRUE,
                ] ),
                'team_description' => form_textarea( 'team_description', self::$locale['TEAM_041'], $this->teamdata['team_description'], [
                    'inline'    => TRUE,
                    'html'      => TRUE,
                    'form_name' => 'groupFrm'
                ] ),
                'team_status'      => form_select( 'team_status', self::$locale['TEAM_043'], $this->teamdata['team_status'], [
                    'inline'      => TRUE,
                    'options'     => [1 => self::$locale['TEAM_048'], 0 => self::$locale['TEAM_049']],
                    'placeholder' => self::$locale['choose'],
                ] ),
                'team_email'       => form_text( 'team_email', self::$locale['TEAM_042'], $this->teamdata['team_email'], [
                    'type'       => 'email',
                    'required'   => TRUE,
                    'inline'     => TRUE,
                    'max_length' => '100',
                    'error_text' => self::$locale['TEAM_058'],
                    //'ext_tip'    => $ext_tip
                ] ),
                'team_phone'       => form_text( 'team_phone', self::$locale['TEAM_044'], $this->teamdata['team_phone'], [
                    'inline'      => TRUE,
                    'number'      => TRUE,
                    'max_length'  => 20,
                    'placeholder' => '+36301234567'
                ] ),
                'team_web'         => form_text( 'team_web', self::$locale['TEAM_045'], $this->teamdata['team_web'], [
                    'inline'      => TRUE,
                    'type'        => 'url',
                    'regex'       => 'http(s)?\:\/\/(.*?)',
                    'placeholder' => 'https://fusionhu.com'
                ] ),
                'team_language'    => multilang_table( "TEAM" ) ? form_select( 'team_language[]', self::$locale['language'], $this->teamdata['team_language'], [
                    'inline'      => TRUE,
                    'options'     => fusion_get_enabled_languages(),
                    'placeholder' => self::$locale['choose'],
                    'inner_width' => '100%',
                    'multiple'    => TRUE
                ] ) : form_hidden( 'team_language', '', $this->teamdata['team_language'] ),
                'butonsave'        => form_button( 'save_user', self::$locale['save'], self::$locale['save'], ['class' => 'btn-sm btn-primary', 'icon' => 'fa fa-floppy-o'] ),
                'closeform'        => closeform()
            ];
            groupForm( $info );
        } else {
            redirect( FUSION_SELF );
        }
    }

    public function teamUserDel( $id = NULL ) {
        dbquery( "UPDATE " . DB_TEAM . " SET team_active = :active, team_status = :status WHERE team_id = :teamid", [':active' => '1', ':status' => 0, ':teamid' => (int)$id] );
    }

}
